@@ -1,6 +1,6 @@
 package Gearman::Client;
 use version ();
-$Gearman::Client::VERSION = version->declare("2.002.004");
+$Gearman::Client::VERSION = version->declare("2.003_001");
 
 use strict;
 use warnings;
@@ -168,14 +168,10 @@ use Gearman::Task;
 use Gearman::Taskset;
 use Gearman::JobStatus;
 use Time::HiRes;
-use Ref::Util qw/
-    is_plain_scalarref
-    is_ref
-    /;
 
 sub new {
     my ($self, %opts) = @_;
-    unless (is_ref($self)) {
+    unless (ref $self) {
         $self = fields::new($self);
     }
 
@@ -354,7 +350,7 @@ sub get_job_server_clients {
 sub _get_task_from_args {
     my $self = shift;
     my $task;
-    if (is_ref($_[0])) {
+    if (ref $_[0]) {
         $task = shift;
         $task->isa("Gearman::Task")
             || Carp::croak("Argument isn't a Gearman::Task");
@@ -363,12 +359,12 @@ sub _get_task_from_args {
         my $func   = shift;
         my $arg_p  = shift;
         my $opts   = shift;
-        my $argref = is_ref($arg_p) ? $arg_p : \$arg_p;
-        is_plain_scalarref($argref)
-            || Carp::croak("Function argument must be scalar or scalarref");
+        my $argref = ref $arg_p ? $arg_p : \$arg_p;
+        Carp::croak("Function argument must be scalar or scalarref")
+            unless ref $argref eq "SCALAR";
 
         $task = Gearman::Task->new($func, $argref, $opts);
-    } ## end else [ if (is_ref($_[0])) ]
+    } ## end else [ if (ref $_[0]) ]
     return $task;
 
 } ## end sub _get_task_from_args
@@ -379,30 +375,24 @@ sub _get_task_from_args {
 
 given a (func, arg_p, opts?)
 
-B<return> either undef (on fail) or scalarref of result
+B<return> scalarref of WORK_COMPLETE result
 
 =cut
 
 sub do_task {
     my $self = shift;
     my $task = $self->_get_task_from_args(@_);
-
     my $ret     = undef;
-    my $did_err = 0;
 
     $task->{on_complete} = sub {
         $ret = shift;
     };
 
-    $task->{on_fail} = sub {
-        $did_err = 1;
-    };
-
     my $ts = $self->new_task_set;
     $ts->add_task($task);
     $ts->wait(timeout => $task->timeout);
 
-    return $did_err ? undef : $ret;
+    return $ret;
 } ## end sub do_task
 
 =head2 dispatch_background($func, $arg_p, $opts)
