@@ -1,16 +1,12 @@
 package Gearman::Job;
 use version ();
-$Gearman::Job::VERSION = version->declare("2.002.004");
+$Gearman::Job::VERSION = version->declare("2.003_001");
 
 use strict;
 use warnings;
 
 use Gearman::Util ();
 use Carp ();
-use Ref::Util qw/
-    is_plain_scalarref
-    is_ref
-    /;
 
 =head1 NAME
 
@@ -29,19 +25,24 @@ use fields (
     'func',
     'argref',
     'handle',
-    'jss',    # job server's socket
+
+    # job server's socket
+    'jss',
+
+    # job server
+    'js',
 );
 
 sub new {
-    my ($self, $func, $argref, $handle, $jss) = @_;
-    unless (is_ref($self)) {
+    my ($self, %arg) = @_;
+    unless (ref $self) {
         $self = fields::new($self);
     }
 
-    $self->{func}   = $func;
-    $self->{handle} = $handle;
-    $self->{argref} = $argref;
-    $self->{jss}    = $jss;
+    while(my ($k, $v) = each(%arg)) {
+      $self->{$k} = $v;
+    }
+
     return $self;
 } ## end sub new
 
@@ -71,8 +72,7 @@ sub set_status {
 =cut
 
 sub argref {
-    my $self = shift;
-    return $self->{argref};
+    return shift->{argref};
 }
 
 =head2 arg()
@@ -82,8 +82,7 @@ B<return> the scalar argument that the client sent to the job server.
 =cut
 
 sub arg {
-    my $self = shift;
-    return ${ $self->{argref} };
+    return ${ shift->{argref} };
 }
 
 =head2 handle()
@@ -93,7 +92,7 @@ B<return> handle
 =cut
 
 sub handle {
-    my $self = shift;
-    return $self->{handle};
+    return shift->{handle};
 }
 
+1;
