@@ -1,6 +1,6 @@
 package Gearman::Task;
 use version;
-$Gearman::Task::VERSION = version->declare("2.002.004");
+$Gearman::Task::VERSION = version->declare("2.003.001");
 
 use strict;
 use warnings;
@@ -78,15 +78,42 @@ A subroutine reference to be invoked if the task emits status updates.
 Arguments passed to the subref are ($numerator, $denominator), where those
 are left up to the client and job to determine.
 
+=item * on_warning
+
+A subroutine reference to be invoked if the task emits status updates.
+Arguments passed to the subref are ($numerator, $denominator), where those
+are left up to the client and job to determine.
+
 =item * retry_count
 
 Number of times job will be retried if there are failures.  Defaults to 0.
 
 =item * high_priority
 
+B<the option high_priority is deprecated>. Use C<< priority => high >> instead.
 Boolean, whether this job should take priority over other jobs already
 enqueued.
 
+=item * priority
+
+valid value:
+
+=over
+
+=item
+
+high
+
+=item
+
+normal (defaul)
+
+=item
+
+low
+
+=back
+
 =item * timeout
 
 Automatically fail, calling your on_fail callback, after this many
@@ -121,8 +148,10 @@ use fields (
     # opts from client:
     'uniq',
     'on_complete',
+    'on_data',
     'on_fail',
     'on_exception',
+    'on_warning',
     'on_retry',
     'on_status',
     'on_post_hooks',
@@ -152,6 +181,7 @@ use fields (
 
     # hookname -> coderef
     'hooks',
+    'priority',
 );
 
 # constructor, given: ($func, $argref, $opts);
@@ -174,16 +204,20 @@ sub new {
         background
         high_priority
         on_complete
+        on_data
         on_exception
         on_fail
         on_retry
         on_status
+        on_warning
         retry_count
         timeout
         try_timeout
         uniq
         /;
 
+    $self->_priority(delete $opts->{priority});
+
     $self->{retry_count} ||= 0;
 
     # bool: if success or fail has been called yet on this.
@@ -302,11 +336,9 @@ B<return> Gearman::Util::pack_req_command(mode, func, uniq, argref)
 
 sub pack_submit_packet {
     my ($self, $client) = @_;
-    my $func = $self->{func};
-
-    if ($client && $client->prefix()) {
-        $func = join "\t", $client->prefix(), $self->{func};
-    }
+    # $client should be optional for sake of Gearman::Client::Async
+    # see https://github.com/p-alik/perl-Gearman/issues/10
+    my $func = $client ? $client->func($self->{func}) : $self->{func};
 
     return Gearman::Util::pack_req_command(
         $self->mode,
@@ -380,6 +412,9 @@ run on_exception if defined
 
 sub exception {
     my ($self, $exc_ref) = @_;
+
+    #FIXME the only on_exception callback get dereferenced value
+    # could it be changed without damage?
     my $exception = Storable::thaw($$exc_ref);
     $self->{on_exception}->($$exception) if $self->{on_exception};
     return;
@@ -416,6 +451,36 @@ sub status {
     $self->{on_status}->($nu, $de);
 } ## end sub status
 
+=head2 data()
+
+invokes C<on_data> callback if worker sends work_data notification.
+
+=cut
+
+sub data {
+    my $self = shift;
+    return if $self->{is_finished};
+    my $result_ref = shift;
+
+    $self->{on_data}->($result_ref) if $self->{on_data};
+} ## end sub data
+
+=head2 warning($message)
+
+invokes C<on_warning> callback if worker sends work_warning notification.
+
+=cut
+
+sub warning {
+    my $self = shift;
+    $self->{is_finished} && return;
+    $self->{on_warning} || return;
+
+    my $msg = shift;
+
+    $self->{on_warning}->($msg);
+} ## end sub warning
+
 =head2 handle()
 
 getter
@@ -527,25 +592,69 @@ sub timeout {
 
 =head2 mode()
 
-B<return> mode in depends of background and hight_priority
+B<return> mode in depends of background and priority
 
 =cut
 
 sub mode {
     my $self = shift;
-    return $self->{background}
-        ? (
-        $self->{high_priority}
-        ? "submit_job_high_bg"
-        : "submit_job_bg"
-        )
-        : (
-        $self->{high_priority}
-        ? "submit_job_high"
-        : "submit_job"
-        );
+    my $mode = "submit_job";
+    if ($self->_priority() ne "normal") {
+        $mode .= "_" . $self->_priority();
+    }
+
+    if ($self->{background}) {
+        $mode .= "_bg";
+    }
+
+    return $mode;
 } ## end sub mode
 
+#=head2 _priority($priority)
+#
+#set/get priority
+#
+#valid C<$priority> value
+#
+#=over
+#
+#=item
+#
+#high
+#
+#=item
+#
+#normal (default)
+#
+#=item
+#
+#low
+#
+#=back
+#
+#=cut
+
+sub _priority {
+    my ($self, $priority) = @_;
+    if ($self->{high_priority}) {
+        warn <<'HERE';
+Gearman::Task key high_priority is deprecated.
+Use priority => "high" instead
+HERE
+        $self->{priority} = "high";
+        delete($self->{high_priority});
+    } ## end if ($self->{high_priority...})
+
+    if ($priority) {
+        $priority =~ /^(high|normal|low)$/
+            || Carp::croak "unsupported priority value";
+        $self->{priority} = $priority;
+    }
+    $self->{priority} ||= "normal";
+
+    return $self->{priority};
+} ## end sub _priority
+
 1;
 __END__
 
