@@ -1,6 +1,6 @@
 package Gearman::Worker;
 use version;
-$Gearman::Worker::VERSION = version->declare("2.002.004");
+$Gearman::Worker::VERSION = version->declare("2.003.001");
 
 use strict;
 use warnings;
@@ -100,9 +100,10 @@ I<sum> job.
 
 #TODO: retries?
 #
-use Gearman::Util;
+use Carp          ();
+use Gearman::Util ();
 use Gearman::Job;
-use Carp ();
+use Storable ();
 
 use fields (
     'last_connect_fail',    # host:port -> unixtime
@@ -116,26 +117,24 @@ use fields (
                     #   sock can never disconnect or timeout, etc..
 );
 
-BEGIN {
-    my $storable = eval { require Storable; 1 }
-        if !defined &THROW_EXCEPTIONS || THROW_EXCEPTIONS();
-
-    $storable ||= 0;
-
-    if (defined &THROW_EXCEPTIONS) {
-        die "Exceptions support requires Storable: $@";
-    }
-    else {
-        eval "sub THROW_EXCEPTIONS () { $storable }";
-        die "Couldn't define THROW_EXCEPTIONS: $@\n" if $@;
-    }
-} ## end BEGIN
-
 sub new {
     my ($class, %opts) = @_;
     my $self = $class;
     $self = fields::new($class) unless ref $self;
 
+    if ($ENV{GEARMAN_WORKER_USE_STDIO}) {
+        if ($opts{job_servers}) {
+            warn join ' ', __PACKAGE__,
+                'ignores job_servers if $ENV{GEARMAN_WORKER_USE_STDIO} is set';
+
+            # delete job_servers to insure Gearman::Objects
+            # does not treat correspondent object property
+            delete($opts{job_servers});
+        } ## end if ($opts{job_servers})
+    } ## end if ($ENV{GEARMAN_WORKER_USE_STDIO...})
+
+    $self->SUPER::new(%opts);
+
     if ($ENV{GEARMAN_WORKER_USE_STDIO}) {
         open my $sock, '+<&', \*STDIN
             or die "Unable to dup STDIN to socket for worker to use.";
@@ -144,131 +143,17 @@ sub new {
 
         die "Unable to initialize connection to gearmand"
             unless $self->_on_connect($sock);
-        if ($opts{job_servers}) {
-            warn join ' ', __PACKAGE__,
-                'ignores job_servers if $ENV{GEARMAN_WORKER_USE_STDIO} is set';
-
-            delete($opts{job_servers});
-        } ## end if ($opts{job_servers})
     } ## end if ($ENV{GEARMAN_WORKER_USE_STDIO...})
 
-    $self->SUPER::new(%opts);
-
     $self->{last_connect_fail} = {};
     $self->{down_since}        = {};
     $self->{can}               = {};
     $self->{timeouts}          = {};
-    $self->{client_id} = join("", map { chr(int(rand(26)) + 97) } (1 .. 30));
+    $self->{client_id} = join('', map { chr(int(rand(26)) + 97) } (1 .. 30));
 
     return $self;
 } ## end sub new
 
-#
-# _get_js_sock($js, %opts)
-#
-sub _get_js_sock {
-    my ($self, $js, %opts) = @_;
-    $js || return;
-
-    my $js_str     = $self->_js_str($js);
-    my $on_connect = delete $opts{on_connect};
-
-    # Someday should warn when called with extra opts.
-
-    warn "getting job server socket: $js_str" if $self->debug;
-
-    # special case, if we're a child process of a gearman::server
-    # parent process, talking over a unix pipe...
-    return $self->{parent_pipe} if $self->{parent_pipe};
-
-    if (my $sock = $self->_sock_cache($js)) {
-        return $sock if getpeername($sock);
-
-        # delete cached sock
-        $self->_sock_cache($js, undef, 1);
-    } ## end if (my $sock = $self->...)
-
-    my $now        = time;
-    my $down_since = $self->{down_since}{$js_str};
-    if ($down_since) {
-        warn "job server down since $down_since" if $self->debug;
-
-        my $down_for = $now - $down_since;
-        my $retry_period = $down_for > 60 ? 30 : (int($down_for / 2) + 1);
-        if ($self->{last_connect_fail}{$js_str} > $now - $retry_period) {
-            return;
-        }
-    } ## end if ($down_since)
-
-    warn "connecting to '$js_str'" if $self->debug;
-
-    my $sock = $self->socket($js, 1);
-    unless ($sock) {
-        $self->{down_since}{$js_str} ||= $now;
-        $self->{last_connect_fail}{$js_str} = $now;
-
-        return;
-    } ## end unless ($sock)
-
-    delete $self->{last_connect_fail}{$js_str};
-    delete $self->{down_since}{$js_str};
-
-    $sock->autoflush(1);
-    $self->sock_nodelay($sock);
-
-    $self->_sock_cache($js, $sock);
-
-    unless ($self->_on_connect($sock) && $on_connect && $on_connect->($sock)) {
-
-        # delete
-        $self->_sock_cache($js, undef, 1);
-        return;
-    } ## end unless ($self->_on_connect...)
-
-    return $sock;
-} ## end sub _get_js_sock
-
-#
-# _on_connect($sock)
-#
-# Housekeeping things to do on connection to a server. Method call
-# with one argument being the 'socket' we're going to take care of.
-# returns true on success, false on failure.
-#
-sub _on_connect {
-    my ($self, $sock) = @_;
-
-    my $cid_req
-        = Gearman::Util::pack_req_command("set_client_id", $self->{client_id});
-    return undef unless Gearman::Util::send_req($sock, \$cid_req);
-
-    # get this socket's state caught-up
-    foreach my $ability (keys %{ $self->{can} }) {
-        my $timeout = $self->{timeouts}->{$ability};
-        unless ($self->_set_ability($sock, $ability, $timeout)) {
-            return;
-        }
-    } ## end foreach my $ability (keys %...)
-
-    return 1;
-} ## end sub _on_connect
-
-#
-# _set_ability($sock, $ability, $timeout)
-#
-sub _set_ability {
-    my ($self, $sock, $ability, $timeout) = @_;
-    my $req;
-    if (defined $timeout) {
-        $req = Gearman::Util::pack_req_command("can_do_timeout",
-            "$ability\0$timeout");
-    }
-    else {
-        $req = Gearman::Util::pack_req_command("can_do", $ability);
-    }
-    return Gearman::Util::send_req($sock, \$req);
-} ## end sub _set_ability
-
 =head2 reset_abilities
 
 tell all the jobservers that this worker can't do anything
@@ -277,13 +162,13 @@ tell all the jobservers that this worker can't do anything
 
 sub reset_abilities {
     my $self = shift;
-    my $req  = Gearman::Util::pack_req_command("reset_abilities");
+    my $req  = _rc("reset_abilities");
     foreach my $js (@{ $self->{job_servers} }) {
         my $jss = $self->_get_js_sock($js)
             or next;
 
-        unless (Gearman::Util::send_req($jss, \$req)) {
-            $self->uncache_sock($js, "err_write_reset_abilities");
+        unless (_send($jss, $req)) {
+            $self->_uncache_sock($js, "err_write_reset_abilities");
         }
     } ## end foreach my $js (@{ $self->{...}})
 
@@ -291,14 +176,14 @@ sub reset_abilities {
     $self->{timeouts} = {};
 } ## end sub reset_abilities
 
-=head2 uncache_sock($ipport, $reason)
+=head2 _uncache_sock($js, $reason)
 
 close TCP connection
 
 =cut
 
-sub uncache_sock {
-    my ($self, $ipport, $reason) = @_;
+sub _uncache_sock {
+    my ($self, $js, $reason) = @_;
 
     # we can't reconnect as a child process, so all we can do is die and hope our
     # parent process respawns us...
@@ -307,8 +192,8 @@ sub uncache_sock {
 
     # normal case, we just close this TCP connection and we'll reconnect later.
     # delete cached sock
-    $self->_sock_cache($ipport, undef, 1);
-} ## end sub uncache_sock
+    $self->_sock_cache($js, undef, 1);
+} ## end sub _uncache_sock
 
 =head2 work(%opts)
 
@@ -317,21 +202,23 @@ You can pass "stop_if", "on_start", "on_complete" and "on_fail" callbacks in I<%
 
 =cut
 
+my %job_done;
+
 sub work {
     my ($self, %opts) = @_;
-    my $stop_if     = delete $opts{'stop_if'} || sub {0};
+    my $stop_if     = delete($opts{stop_if}) || sub {0};
     my $complete_cb = delete $opts{on_complete};
     my $fail_cb     = delete $opts{on_fail};
     my $start_cb    = delete $opts{on_start};
     die "Unknown opts" if %opts;
 
-    my $grab_req     = Gearman::Util::pack_req_command("grab_job");
-    my $presleep_req = Gearman::Util::pack_req_command("pre_sleep");
+    my $grab_req     = _rc("grab_job");
+    my $presleep_req = _rc("pre_sleep");
 
     my $last_job_time;
 
     my $on_connect = sub {
-        return Gearman::Util::send_req($_[0], \$presleep_req);
+        return _send($_[0], $presleep_req);
     };
 
     my %js_map = map { $self->_js_str($_) => $_ } $self->job_servers;
@@ -369,17 +256,18 @@ sub work {
             # send_req, etc) this testing has been done manually, at
             # least.
 
-            unless (Gearman::Util::send_req($jss, \$grab_req)) {
+            unless (_send($jss, $grab_req)) {
                 if ($!{EPIPE} && $self->{parent_pipe}) {
 
                     # our parent process died, so let's just quit
                     # gracefully.
                     exit(0);
                 } ## end if ($!{EPIPE} && $self...)
-                $self->uncache_sock($js, "grab_job_timeout");
+
+                $self->_uncache_sock($js, "grab_job_timeout");
                 delete $last_update_time{$js_str};
                 next;
-            } ## end unless (Gearman::Util::send_req...)
+            } ## end unless (_send($jss, $grab_req...))
 
             # if we're a child process talking over a unix pipe, give more
             # time, since we know there are no network issues, and also
@@ -388,7 +276,7 @@ sub work {
             my $timeout = $self->{parent_pipe} ? 5 : 0.50;
             unless (Gearman::Util::wait_for_readability($jss->fileno, $timeout))
             {
-                $self->uncache_sock($js, "grab_job_timeout");
+                $self->_uncache_sock($js, "grab_job_timeout");
                 delete $last_update_time{$js_str};
                 next;
             } ## end unless (Gearman::Util::wait_for_readability...)
@@ -398,23 +286,24 @@ sub work {
                 my $err;
                 $res = Gearman::Util::read_res_packet($jss, \$err);
                 unless ($res) {
-                    $self->uncache_sock($js, "read_res_error");
+                    $self->_uncache_sock($js, "read_res_error");
                     delete $last_update_time{$js_str};
                     next;
                 }
             } while ($res->{type} eq "noop");
 
             if ($res->{type} eq "no_job") {
-                unless (Gearman::Util::send_req($jss, \$presleep_req)) {
+                unless (_send($jss, $presleep_req)) {
                     delete $last_update_time{$js_str};
-                    $self->uncache_sock($js, "write_presleep_error");
+                    $self->_uncache_sock($js, "write_presleep_error");
                 }
-                $last_update_time{$js} = time;
+                $last_update_time{$js_str} = time;
                 next;
             } ## end if ($res->{type} eq "no_job")
 
             unless ($res->{type} eq "job_assign") {
                 my $msg = "Uh, wasn't expecting a $res->{type} packet.";
+
                 if ($res->{type} eq "error") {
                     $msg .= " [${$res->{blobref}}]\n";
                     $msg =~ s/\0/ -- /g;
@@ -422,11 +311,16 @@ sub work {
                 die $msg;
             } ## end unless ($res->{type} eq "job_assign")
 
-            ${ $res->{'blobref'} } =~ s/^(.+?)\0(.+?)\0//
+            ${ $res->{blobref} } =~ s/^(.+?)\0(.+?)\0//
                 or die "Uh, regexp on job_assign failed";
             my ($handle, $ability) = ($1, $2);
-            my $job
-                = Gearman::Job->new($ability, $res->{'blobref'}, $handle, $jss);
+            my $job = Gearman::Job->new(
+                func   => $ability,
+                argref => $res->{blobref},
+                handle => $handle,
+                jss    => $jss,
+                js     => $js
+            );
 
             my $jobhandle = join("//", $js_str, $job->handle);
             $start_cb->($jobhandle) if $start_cb;
@@ -437,32 +331,38 @@ sub work {
             warn "Job '$ability' died: $err" if $err;
 
             $last_update_time{$js_str} = $last_job_time = time();
+            if ($err) {
 
-            if (THROW_EXCEPTIONS && $err) {
+                #TODO should be work_exception replaced by work_fail?
+                # see 75b65e1
                 my $exception_req
-                    = Gearman::Util::pack_req_command("work_exception",
-                    join("\0", $handle, Storable::nfreeze(\$err)));
-                unless (Gearman::Util::send_req($jss, \$exception_req)) {
-                    $self->uncache_sock($js, "write_res_error");
+                    = _rc("work_exception",
+                    _join0($handle, Storable::nfreeze(\$err)));
+                unless (_send($jss, $exception_req)) {
+                    $self->_uncache_sock($js, "write_res_error");
                     next;
                 }
-            } ## end if (THROW_EXCEPTIONS &&...)
+            } ## end if ($err)
 
-            my $work_req;
-            if (defined $ret) {
-                my $rv = ref $ret ? $$ret : $ret;
-                $work_req = Gearman::Util::pack_req_command("work_complete",
-                    "$handle\0$rv");
+            if (!defined $job_done{ $job->handle }) {
+                if (defined $ret) {
+                    $self->send_work_complete($job, $ret);
+                }
+                else {
+                    $self->send_work_fail($job);
+                }
+            } ## end if (!defined $job_done...)
+
+            my $done = delete $job_done{ $job->handle };
+            if ($done->{command} eq "work_complete") {
                 $complete_cb->($jobhandle, $ret) if $complete_cb;
-            } ## end if (defined $ret)
+            }
             else {
-                $work_req
-                    = Gearman::Util::pack_req_command("work_fail", $handle);
                 $fail_cb->($jobhandle, $err) if $fail_cb;
             }
 
-            unless (Gearman::Util::send_req($jss, \$work_req)) {
-                $self->uncache_sock($js, "write_res_error");
+            unless ($done->{result}) {
+                $self->_uncache_sock($js, "write_res_error");
                 next;
             }
 
@@ -519,22 +419,22 @@ sub work {
 
 =head2 $worker->register_function($funcname, $timeout, $subref)
 
-Registers the function I<$funcname> as being provided by the worker
-I<$worker>, and advertises these capabilities to all of the job servers
+Registers the function C<$funcname> as being provided by the worker
+C<$worker>, and advertises these capabilities to all of the job servers
 defined in this worker.
 
-I<$subref> must be a subroutine reference that will be invoked when the
+C<$subref> must be a subroutine reference that will be invoked when the
 worker receives a request for this function. It will be passed a
-I<Gearman::Job> object representing the job that has been received by the
+L<Gearman::Job> object representing the job that has been received by the
 worker.
 
-I<$timeout> is an optional parameter specifying how long the jobserver will
+C<$timeout> is an optional parameter specifying how long the jobserver will
 wait for your subroutine to give an answer. Exceeding this time will result
 in the jobserver reassigning the task and ignoring your result. This prevents
 a gimpy worker from ruining the 'user experience' in many situations.
 
-The subroutine reference can return a return value, which will be sent back
-to the job server.
+B<return> C<< _register_all(can_do request) >>
+
 =cut
 
 sub register_function {
@@ -543,58 +443,43 @@ sub register_function {
     my $timeout = shift unless (ref $_[0] eq 'CODE');
     my $subref  = shift;
 
-    my $prefix = $self->prefix;
-    my $ability = defined($prefix) ? join("\t", $prefix, $func) : $func;
+    my $ability = $self->func($func);
 
     my $req;
     if (defined $timeout) {
-        $req = Gearman::Util::pack_req_command("can_do_timeout",
-            "$ability\0$timeout");
+        $req = _rc("can_do_timeout", _join0($ability, $timeout));
         $self->{timeouts}{$ability} = $timeout;
     }
     else {
-        $req = Gearman::Util::pack_req_command("can_do", $ability);
+        $req = _rc("can_do", $ability);
     }
 
-    $self->_register_all($req);
     $self->{can}{$ability} = $subref;
+
+    return $self->_register_all($req);
 } ## end sub register_function
 
 =head2 unregister_function($funcname)
 
+send cant_do C<$funcname> request to L<job_servers>
+
+B<return> C<< _register_all(cant_do) >>
+
 =cut
 
 sub unregister_function {
     my ($self, $func) = @_;
-    my $prefix = $self->prefix;
-    my $ability = defined($prefix) ? join("\t", $prefix, $func) : $func;
-
-    my $req = Gearman::Util::pack_req_command("cant_do", $ability);
-
-    $self->_register_all($req);
+    my $ability = $self->func($func);
     delete $self->{can}{$ability};
+
+    my $req = _rc("cant_do", $ability);
+    return $self->_register_all($req);
 } ## end sub unregister_function
 
-#
-# _register_all($req)
-#
-sub _register_all {
-    my ($self, $req) = @_;
-
-    foreach my $js ($self->job_servers()) {
-        my $jss = $self->_get_js_sock($js)
-            or next;
-
-        unless (Gearman::Util::send_req($jss, \$req)) {
-            $self->uncache_sock($js, "write_register_func_error");
-        }
-    } ## end foreach my $js ($self->job_servers...)
-} ## end sub _register_all
-
 =head2 job_servers(@servers)
 
-override L<Gearman::Objects> method to skip job server initialization
-if defined C<$ENV{GEARMAN_WORKER_USE_STDIO}>
+Override L<Gearman::Objects> method to skip job server initialization if
+wokring with L<Gearman::Server>.
 
 Calling this method will do nothing in a worker that is running as a child
 process of a gearman server.
@@ -603,11 +488,255 @@ process of a gearman server.
 
 sub job_servers {
     my $self = shift;
-    return if ($ENV{GEARMAN_WORKER_USE_STDIO});
+    $ENV{GEARMAN_WORKER_USE_STDIO} && return $self->{job_servers};
 
     return $self->SUPER::job_servers(@_);
 } ## end sub job_servers
 
+=head2 send_work_complete($job, $v)
+
+notify the server (and listening clients) that job completed successfully
+
+=cut
+
+sub send_work_complete {
+    return shift->_finish_job_request("work_complete", @_);
+}
+
+=head2 send_work_data($job, $data)
+
+Use this method to update the client with data from a running job.
+
+=cut
+
+sub send_work_data {
+    my ($self, $job, $data) = @_;
+    return $self->_job_request("work_data", $job,
+        ref($data) ? ${$data} : $data);
+}
+
+=head2 send_work_warning($job, $message)
+
+Use this method to send a warning C<$message> to the server (and any listening clients) with regard to the running C<job>.
+
+=cut
+
+sub send_work_warning {
+    my ($self, $job, $msg) = @_;
+    return $self->_job_request("work_warning", $job, $msg);
+}
+
+# =head2 send_work_exception($job, $exception)
+
+# Use this method to notify the server (and any listening clients) that the C<job> failed with the given C<$exception>.
+
+# =cut
+
+# sub send_work_exception {
+#     my ($self, $job, $exc) = @_;
+#     return $self->_job_request("work_exception", $job, $exc);
+# }
+
+=head2 send_work_fail($job, [$message])
+
+Use this method to notify the server (and any listening clients) that the job failed.
+
+=cut
+
+sub send_work_fail {
+    my ($self) = shift;
+    return $self->_finish_job_request("work_fail", @_);
+}
+
+=head2 send_work_status($job, $numerator, $denominator)
+
+Use this method to send periodically to the server status update for long running jobs to update the percentage
+complete.
+
+=cut
+
+sub send_work_status {
+    my ($self, $job, $numerator, $denominator) = @_;
+    return $self->_job_request("work_status", $job, $numerator, $denominator);
+}
+
+# _finish_job_request($cmd, $job, [$v])
+#
+# send some data or message to the client for finished job
+# $cmd = work_complete || work_fail
+#
+sub _finish_job_request {
+    my ($self, $cmd, $job, $v) = @_;
+    my $res = $self->_job_request($cmd, $job, ref($v) ? ${$v} : $v);
+
+    # set job done flag because work method check it
+    $job_done{ $job->handle } = { command => $cmd, result => $res };
+
+    return $res;
+} ## end sub _finish_job_request
+
+# _job_request($cmd, $job, [$v])
+#
+# send some data to the client for the running job
+#
+sub _job_request {
+    my ($self, $cmd, $job, $v) = @_;
+    my $req = _rc($cmd, $v ? _join0($job->handle, $v) : $job->handle);
+
+    return _send($job->{jss}, $req);
+} ## end sub _job_request
+
+#
+# _register_all($req)
+#
+sub _register_all {
+    my ($self, $req) = @_;
+
+    my $count       = 0;
+    my @job_servers = $self->job_servers();
+    foreach my $js (@job_servers) {
+        my $jss = $self->_get_js_sock($js)
+            or next;
+
+        unless (_send($jss, $req)) {
+            $self->_uncache_sock($js, "write_register_func_error");
+            next;
+        }
+        $count++;
+    } ## end foreach my $js (@job_servers)
+
+    return $count && $count == scalar(@job_servers);
+} ## end sub _register_all
+
+#
+# _get_js_sock($js, %opts)
+#
+sub _get_js_sock {
+    my ($self, $js, %opts) = @_;
+    $js || return;
+
+    my $js_str     = $self->_js_str($js);
+    my $on_connect = delete $opts{on_connect};
+
+    # Someday should warn when called with extra opts.
+
+    warn "getting job server socket: $js_str" if $self->debug;
+
+    # special case, if we're a child process of a gearman::server
+    # parent process, talking over a unix pipe...
+    return $self->{parent_pipe} if $self->{parent_pipe};
+
+    if (my $sock = $self->_sock_cache($js)) {
+        return $sock if getpeername($sock);
+
+        # delete cached sock
+        $self->_sock_cache($js, undef, 1);
+    } ## end if (my $sock = $self->...)
+
+    my $now        = time;
+    my $down_since = $self->{down_since}{$js_str};
+    if ($down_since) {
+        warn "job server down since $down_since" if $self->debug;
+
+        my $down_for = $now - $down_since;
+        my $retry_period = $down_for > 60 ? 30 : (int($down_for / 2) + 1);
+        if ($self->{last_connect_fail}{$js_str} > $now - $retry_period) {
+            return;
+        }
+    } ## end if ($down_since)
+
+    warn "connecting to '$js_str'" if $self->debug;
+
+    my $sock = $self->socket($js, 1);
+    unless ($sock) {
+        $self->{down_since}{$js_str} ||= $now;
+        $self->{last_connect_fail}{$js_str} = $now;
+
+        return;
+    } ## end unless ($sock)
+
+    delete $self->{last_connect_fail}{$js_str};
+    delete $self->{down_since}{$js_str};
+
+    $sock->autoflush(1);
+    $self->sock_nodelay($sock);
+
+    $self->_sock_cache($js, $sock);
+
+    my $ok = $on_connect ? $on_connect->($sock) : $self->_on_connect($sock);
+    unless ($ok) {
+
+        # delete
+        $self->_sock_cache($js, undef, 1);
+        return;
+    } ## end unless ($ok)
+
+    return $sock;
+} ## end sub _get_js_sock
+
+#
+# _on_connect($sock)
+#
+# Housekeeping things to do on connection to a server. Method call
+# with one argument being the 'socket' we're going to take care of.
+# returns true on success, false on failure.
+#
+sub _on_connect {
+    my ($self, $sock) = @_;
+
+    my $cid_req = _rc("set_client_id", $self->{client_id});
+    return unless _send($sock, $cid_req);
+
+    # get this socket's state caught-up
+    foreach my $ability (keys %{ $self->{can} }) {
+        my $timeout = $self->{timeouts}->{$ability};
+        unless ($self->_set_ability($sock, $ability, $timeout)) {
+            return;
+        }
+    } ## end foreach my $ability (keys %...)
+
+    return 1;
+} ## end sub _on_connect
+
+#
+# _set_ability($sock, $ability, [$timeout])
+#
+sub _set_ability {
+    my ($self, $sock, $ability, $timeout) = @_;
+    my $req;
+    if (defined $timeout) {
+        $req = _rc("can_do_timeout", _join0($ability, $timeout));
+    }
+    else {
+        $req = _rc("can_do", $ability);
+    }
+    return _send($sock, $req);
+} ## end sub _set_ability
+
+#
+# _send($jss, $req)
+#
+# send C<$req> to C<$jss>
+#
+sub _send {
+    my ($jss, $req) = @_;
+    return Gearman::Util::send_req($jss, \$req);
+}
+
+#
+# _rc($cmd, [@val])
+#
+sub _rc {
+    return Gearman::Util::pack_req_command(@_);
+}
+
+#
+# _join0(@v)
+#
+sub _join0 {
+    return join("\0", @_);
+}
+
 1;
 __END__
 
@@ -617,7 +746,7 @@ Gearman workers can be run as child processes of a parent process
 which embeds L<Gearman::Server>.  When such a parent process
 fork/execs a worker, it sets the environment variable
 GEARMAN_WORKER_USE_STDIO to true before launching the worker. If this
-variable is set to true, then the jobservers function and option for
+variable is set to true, then the L<job_servers|job_servers(@servers)> function and option for
 new() are ignored and the unix socket bound to STDIN/OUT are used
 instead as the IO path to the gearman server.
 
